@@ -1,6 +1,6 @@
 
-from latin.bglobals import *
-from latin.e_pedocerto import check_vowels
+from bglobals import *
+from e_pedocerto import check_vowels
 
 
 
@@ -12,7 +12,7 @@ class top_most:
     def get_atts(self, kind=0):
 ## kind4 is used after co_lemmas5 has been built in j_lasla2
 
-        import latin.w_convert_mod
+        import w_convert_mod
         p ('opening pickles')
 
         self.pos = pi.open_pickle(f'{fold}final_pos')
