@@ -1,5 +1,5 @@
 import pickle, os
-from latin.general_la.abbreviations import *
+from abbreviations import *
 
 
 
