@@ -1,6 +1,6 @@
 from copy import deepcopy
 import unicodedata
-from latin.bglobals import *
+from bglobals import *
 
 
 
